==> fr-homard-10.6.3_2.txz: usr/local/apps/homard/aster_homard_py/aster_homard_2.py <==
# -*- coding: iso-8859-1 -*-
"""
Programme du couplage entre HOMARD et Code_Aster
Recuperation des options dans le fichier de configuration

"""
__revision__ = "V2.4"
#
import os
import string
#
########################## Debut de la fonction ##################################
#
def aster_homard_2 (dict_arguments, fic_conf, message_info) :
#
  """
   But :
     Recuperation des options dans le fichier de configuration

   Arguments :
     1. Environnement : nom du fichier de configuration et nom du fichier de donnees
     2. nom du fichier de configuration
     3. message_info : les messages d'information a completer
  """
#
# 1. code de retour :
  blabla = "\nDans " + __name__ + " : "
  messages_erreur = { 0 : "",
                      1 : "Le fichier de configuration pour HOMARD est inconnu." }
#
#  print blabla, "\nfic_conf :", fic_conf
  variables_conf = {}
  verbose = dict_arguments["verbose"]
#
# 2. Verification
#
  if not os.path.isfile(fic_conf) :
    code_erreur = 1
  else :
    code_erreur = 0
#
  if not code_erreur :
#
# 2. Lecture du fichier
#    Chaque ligne est convertie en une liste 'ligne', puis stockee dans une liste 'les_lignes'
#    On supprime les lignes vides et les lignes de commentaires
#
    if ( verbose ) :
      message_info += "\n.. Fichier de configuration pour HOMARD"
#
    fichier = open (fic_conf,"r")
    tout = fichier.readlines()
    fichier.close()
#
    les_lignes = []
    for ligne in tout :
      if ( len(ligne) > 1 ) :
        if ( ligne[0] != "#" ) :
          mot = string.split(ligne)
          les_lignes.append(mot)
          if ( verbose ) :
            message_info += "\n" + ligne[:-1]
    if ( verbose ) :
      message_info += "\n"
#
# 3. Recherche des infos necessaires
# 3.1. Le mode d'utilisation de HOMARD
#
    mot_cle = "ModeHOMA"
    for indice in range(len(les_lignes)) :
##      print les_lignes[indice][0:]
      if les_lignes[indice][0] == mot_cle :
        variables_conf [mot_cle] = string.atoi(les_lignes[indice][1])
        break
    modehoma = variables_conf [mot_cle]
#
# 3.2. Les autres options et informations liees aux fichiers
#
    mots_cles_option = [ "ListeStd", "NumeIter", "PPBasFic" ]
    mots_cles_fic = { "CCMaiN__":2  }
#
    if modehoma == 1 or modehoma == 3 :
      mots_cles_fic ["HOMaiN__"] = 3
      mots_cles_fic ["HOMaiNP1"] = 3
      mots_cles_fic ["CCMaiN__"] = 2
      mots_cles_fic ["CCMaiNP1"] = 2
      mots_cles_option.append("CCNoMNP1")
      mots_cles_option.append("HOMaiNP1")
#
    if modehoma == 1 :
      mots_cles_fic ["CCIndica"] = 2
      mots_cles_fic ["CCSolN__"] = 2
      mots_cles_fic ["CCSolNP1"] = 2
#
    for mot_cle in mots_cles_option :
      for indice in range(len(les_lignes)) :
        if les_lignes[indice][0] == mot_cle :
          variables_conf [mot_cle] = les_lignes[indice][1]
          break
#
    for mot_cle in mots_cles_fic.keys() :
      place = mots_cles_fic[mot_cle] - 1
      for indice in range(len(les_lignes)) :
        if les_lignes[indice][0] == mot_cle :
          variables_conf [mot_cle+"_fic"] = les_lignes[indice][place]
          break
#
  if verbose :
    l_aux = variables_conf.keys()
    l_aux.sort()
    message_info += ".. variables_conf ="
    for cle in l_aux :
      message_info += "\n  " + cle + " : " + str(variables_conf[cle])
    message_info += "\n"
#
# 4. La fin
#
  variables_conf["code_de_retour"] = code_erreur
#
  if code_erreur :
    saux  =  blabla + "erreur de programmation\n"
    saux += "Fichier " + fic_conf + "\n" + messages_erreur[code_erreur]
  else :
    saux = ""
#
  return code_erreur, message_info, saux, variables_conf
#
##########################  Fin de la fonction  ##################################
#
##########################       Auto-test      ##################################
#
if __name__ == '__main__' :
#
  from aster_homard_utilitaires import verif
  import tempfile
#
  d1 = {'verbose': 0 }
  f1 = "/tmp/tmp"
  m1 = "gabuzome"
  l1_refe = {'code_de_retour': 1}
  l1_calc = aster_homard_2 (d1, f1, m1)
  verif ("Test sur l1", l1_refe, l1_calc)
#
  fic_conf_test = tempfile.mktemp()
  fichier_test = open (fic_conf_test, 'w')
  s = "modehoma 1\n"
  fichier_test.write(s)
  fichier_test.close()
  l2 = fic_conf_test
  l2_refe = {'ModeHOMA': 1, 'code_de_retour': 0}
  l2_calc = aster_homard_2 (l2)
  verif ("Test sur l2", l2_refe, l2_calc)
  os.remove(fic_conf_test)
#

==> fr-homard-11.2.1.txz: usr/local/apps/homard/aster_homard_py/aster_homard_2.py <==
# -*- coding: iso-8859-1 -*-
"""
Programme du couplage entre HOMARD et Code_Aster
Recuperation des options dans le fichier de configuration

"""
__revision__ = "V2.5"
#
import os
import string
#
#========================= Debut de la fonction ==================================
#
def aster_homard_2 (dict_arguments, fic_conf, message_info) :
#
  """
   But :
     Recuperation des options dans le fichier de configuration

   Arguments :
     1. Environnement : nom du fichier de configuration et nom du fichier de donnees
     2. nom du fichier de configuration
     3. message_info : les messages d'information a completer
  """
#
# 1. code de retour :
  blabla = "\nDans " + __name__ + " : "
  messages_erreur = { 0 : "",
                      1 : "Le fichier de configuration pour HOMARD est inconnu." }
#
#  print blabla, "\nfic_conf :", fic_conf
  variables_conf = {}
  verbose = dict_arguments["verbose"]
#
# 2. Verification
#
  if not os.path.isfile(fic_conf) :
    code_erreur = 1
  else :
    code_erreur = 0
#
  if not code_erreur :
#
# 2. Lecture du fichier
#    Chaque ligne est convertie en une liste 'ligne', puis stockee dans une liste 'les_lignes'
#    On supprime les lignes vides et les lignes de commentaires
#
    if ( verbose ) :
      message_info += "\n.. Fichier de configuration pour HOMARD"
#
    fichier = open (fic_conf,"r")
    tout = fichier.readlines()
    fichier.close()
#
    les_lignes = []
    for ligne in tout :
      if ( len(ligne) > 1 ) :
        if ( ligne[0] != "#" ) :
          mot = string.split(ligne)
          les_lignes.append(mot)
          if ( verbose ) :
            message_info += "\n" + ligne[:-1]
    if ( verbose ) :
      message_info += "\n"
#
# 3. Recherche des infos necessaires
# 3.1. Le mode d'utilisation de HOMARD
#
    mot_cle = "ModeHOMA"
    for indice in range(len(les_lignes)) :
##      print les_lignes[indice][0:]
      if les_lignes[indice][0] == mot_cle :
        variables_conf [mot_cle] = string.atoi(les_lignes[indice][1])
        break
    modehoma = variables_conf [mot_cle]
#
# 3.2. Les autres options et informations liees aux fichiers
#
    mots_cles_option = [ "ListeStd", "NumeIter", "PPBasFic" ]
    mots_cles_fic = { "CCMaiN__":2  }
#
    if modehoma == 1 or modehoma == 3 :
      mots_cles_fic ["HOMaiN__"] = 3
      mots_cles_fic ["HOMaiNP1"] = 3
      mots_cles_fic ["CCMaiN__"] = 2
      mots_cles_fic ["CCMaiNP1"] = 2
      mots_cles_option.append("CCNoMNP1")
      mots_cles_option.append("HOMaiNP1")
#
    if modehoma == 1 :
      mots_cles_fic ["CCIndica"] = 2
      mots_cles_fic ["CCSolN__"] = 2
      mots_cles_fic ["CCSolNP1"] = 2
#
    for mot_cle in mots_cles_option :
      for indice in range(len(les_lignes)) :
        if les_lignes[indice][0] == mot_cle :
          variables_conf [mot_cle] = les_lignes[indice][1]
          break
#
    for mot_cle in mots_cles_fic.keys() :
      place = mots_cles_fic[mot_cle] - 1
      for indice in range(len(les_lignes)) :
        if les_lignes[indice][0] == mot_cle :
          variables_conf [mot_cle+"_fic"] = les_lignes[indice][place]
          break
#
  if verbose :
    l_aux = variables_conf.keys()
    l_aux.sort()
    message_info += ".. variables_conf ="
    for cle in l_aux :
      message_info += "\n  " + cle + " : " + str(variables_conf[cle])
    message_info += "\n"
#
# 4. La fin
#
  variables_conf["code_de_retour"] = code_erreur
#
  if code_erreur :
    saux  =  blabla + "erreur de programmation\n"
    saux += "Fichier " + fic_conf + "\n" + messages_erreur[code_erreur]
  else :
    saux = ""
#
  return code_erreur, message_info, saux, variables_conf
#
#=========================  Fin de la fonction ===================================
#
#=========================      Auto-test      ===================================
#
if __name__ == '__main__' :
#
  from aster_homard_utilitaires import verif
  import tempfile
#
  d1 = {'verbose': 0 }
  f1 = "/tmp/tmp"
  m1 = "gabuzome"
  l1_refe = {'code_de_retour': 1}
  l1_calc = aster_homard_2 (d1, f1, m1)
  verif ("Test sur l1", l1_refe, l1_calc)
#
  t_aux = tempfile.mkstemp()
  fic_conf_test = t_aux[1]
  fichier_test = open (fic_conf_test, 'w')
  s = "modehoma 1\n"
  fichier_test.write(s)
  fichier_test.close()
  l2 = fic_conf_test
  l2_refe = {'ModeHOMA': 1, 'code_de_retour': 0}
  l2_calc = aster_homard_2 (l2)
  verif ("Test sur l2", l2_refe, l2_calc)
  os.remove(fic_conf_test)
#
